@@ -199,14 +199,14 @@ class APIView(View):
 class HTMLView(View):
     def __init__(self, *args, **kwargs):
         super(HTMLView, self).__init__(*args, **kwargs)
-        self.html_filename = kwargs.get('html_filename', None)
+        self.template_name = kwargs.get('template_name', None)
 
     def get(self, *args, **kwargs):
-        if self.html_filename is not None:
+        if self.template_name is not None:
             context = {}
             context.update(self.init_kwargs)
             context.update(kwargs)
             context.update(self.request.GET)
-            self.response = render(self.request, self.html_filename, context)
+            self.response = render(self.request, self.template_name, context)
         else:
-            self.response.write('No assigned html template')
\ No newline at end of file
+            raise ValueError, 'Template name is undefined.'
\ No newline at end of file
